<?php
// Script for verifying the correct topology data to use in abgx360 for AP 2.5 games
// Replacement script written by Hadzz. This code is free to be used as you please.
// Message hadzz#4095 on Discord if you find any AP 2.5 XGD2 games not already listed here
// Referenced https://web.archive.org/web/20140111122333/https://spreadsheets.google.com/pub?key=0AmtrXBZ5bMbGdEZYN1JScjFnMGNncF9JSWs3VmhBNXc
// Big thank you to Defosho for this list!
function is_uppercase_hex($str)
{
  return (trim($str, '0..9A..F') == '');
}

function valid_mediaID($id)
{
  return (strlen($id) == 33 && $id[24] == '-' 
    && is_uppercase_hex(substr($id, 0, 24))
    && is_uppercase_hex(substr($id, 25, 8)));
}

function valid_titleID($id)
{
  return (strlen($id) == 8 && is_uppercase_hex($id));
}

// Print the message with [TOP] tag around it, then terminate the script
function print_and_exit($output)
{
  echo '[TOP]' . $output . '[/TOP]';
  exit();
}

// -> Start of the script
// Get the three query strings
$mediaID = $titleID = $discID = '';
if (isset($_GET['m'])) $mediaID = $_GET['m'];
if (isset($_GET['t'])) $titleID = $_GET['t'];
if (isset($_GET['d'])) $discID = $_GET['d'];

// Validate input
if (count($_GET) == 3) {
  if (!valid_mediaID($mediaID) || !valid_mediaID($discID) || !valid_titleID($titleID))
    print_and_exit('INVALID');
} elseif (count($_GET) == 2) {
  if (!valid_mediaID($mediaID) || !valid_titleID($titleID))
    print_and_exit('INVALID');
} else
  print_and_exit('INVALID');

// List of mediaID's of AP2.5 games in which no patch exists
$unsupportedMIDs = array(
  // Halo: Reach XGD3 Beta
  // TID=4D53085B DID=96300C707FB66FE1425639B3-25E73C43
  'DBBADFEBE890F4FAD1126638-FFFFFDEB'
);

// Check if the mediaID is known to be missing patches
if (in_array($mediaID, $unsupportedMIDs, true))
  print_and_exit('MISSING');

// ================ XGD3 ================
// Only one patch for XGD3 games (discID F87A804E)
if ($discID == '0C3DF524599094E6CB87ECC8-F87A804E')
  print_and_exit('TOP_XGD3-DID-F87A804E_v1');
// ============== END XGD3 ==============
else {
  // ================ XGD2 ================
  // Set up arrays for mediaID's of XGD2 games that support topology patches
  // Halo: Reach
  $reachMIDs = array(
    'D5F8036CA497AFADC59687E1-566C10D3',
    'C4C5055F6C2B9A14F475CF27-046D17EE',
    '3C0CB47DCA0AA8CE32F4B454-61F099B6',
    '241AE8BC553934C2327C3054-56D002AE',
    '077604A1B6A4906BDC2FEE76-4896578C',
    '61A1F73AB1D1F4E70F255BCD-0F6E5B5E',
    'C520CE509288429F802A8EDE-25148C14',
    'FD8573EBD621254AF649E985-1826D881',
    '3034EDCC9AB5D62738495F16-42D18BEE',
    '56198EC5187E1E40EC341222-63681F4C'
  );
  // Call of Duty: Modern Warfare 2
  $mw2MIDs   = array(
    'F66327164FA486B27A77BBBF-2C8C0267',
    '9D3070753DEB6B5E68B44018-2BC527C6',
    '5F84DCD5B2B5AA141F44C5DC-4BA1F097',
    '98FAE3ADF9BC01FEF33C9275-6F02EF28',
    '160D59958379F41548FB21C7-11D15B16',
    '8A632D3F3371D09D18485069-61233876',
    'BF8A767BCD79665F211E4567-38BB183D',
    '3DF5EA36147DC8CA72364A0A-3C598793'
  );
  // Call of Duty: Black Ops
  $boMIDs = array(
    'CFD2E6184386829EC2E59087-0AEB2159',
    '6A98C7BA074A172BFA71976A-4D18C76A',
    'E803E41DE2527D254025CCB8-0ED34F47',
    '226004A51B017F6B96D32935-780A0FC4',
    '4528C329C6C840F25755F607-3C8B5AAC',
    '74E523E7789C3214D35F9022-1E0BB99A',
    'F2D8D29D0E1C51CFFFE865F3-7D203A97',
    '28300D74C0336DE51EF1F528-54CDD2BC',
    'F9FBAE6599A8D8C6F47A32E5-0F8FCCCA',
    'F5AE5A9CDD5AE5CF71993572-0A9FBC16'
  );
  // Fable 3
  $f3MIDs = array(
    'C3B33ADB911E3EF2ECF445BA-D99E18E7',
    '41254049736AE4BFCD34CB01-A371069D',
    'F7B500F2A7FFE9CCFEE3EEA3-BF2AB004',
    '7B83566454A6B57EC7C47897-C22D0F2B',
    '463073E5434FC21E7488D5F8-16003BAB',
    'FD1F82BF87DCB15E31C07183-FCC2EE4D',
    'BD9324664A7315D036C5EEFE-637BECDF',
    'B960224095E1476C57D240B7-D782A18E'
  );
  // Need for Speed: Hot Pursuit
  $nfshpMIDs = array(
    'A278D14910A5736BBE4136BF-668ACE20',
    '134F0FC0795DB40DACC8C0A7-B132B42D',
    '08F9CC0FFF43CEB4945E661B-B769147D',
    '0A075150756D31D42ABE2180-A326F0A6',
    '135291650BCD85722CFCE848-D8372CFD',
    '2BE6109612C80ACF243DA39A-B1B8B61D',
    '49D717DBAD0D31E51A0FDB3F-15BEBBFD'
  );
  //Assassin's Creed: Brotherhood
  $acbMIDs = array(
    '85FB4685C7D7D8A762292B0A-CAA468A3',
    '298F341E24EBE1EC9524C655-6D88AE4F',
    'C29635294BCA7B4A141DD99F-F146E5B3',
    '3187E4E49C2D6E735950040E-9D4DB308',
    '811F14C303AA36E306FB7E56-27A19372'
  );
  // Now that arrays are set, find an applicable patch for the game requested.
  // Halo: Reach
  if ($titleID == '4D53085B' && in_array($mediaID, $reachMIDs, true))
    print_and_exit('TOP_XGD2-Reach-MW2-BO_v1');
  // Modern Warfare 2
  elseif ($titleID == '41560817' && in_array($mediaID, $mw2MIDs, true))
    print_and_exit('TOP_XGD2-Reach-MW2-BO_v1');
  // Black Ops
  elseif ($titleID == '41560855' && in_array($mediaID, $boMIDs, true))
    print_and_exit('TOP_XGD2-Reach-MW2-BO_v1');
  // Fable 3
  elseif ($titleID == '4D5308D6' && in_array($mediaID, $f3MIDs, true))
    print_and_exit('TOP_XGD2-Fable3_v1');
  // Need for Speed: Hot Pursuit
  elseif ($titleID == '45410903' && in_array($mediaID, $nfshpMIDs, true))
    print_and_exit('TOP_XGD2-NFSHP_v1');
  // Assassin's Creed: Brotherhood
  elseif ($titleID == '5553085D' && in_array($mediaID, $acbMIDs, true))
    print_and_exit('TOP_XGD2-ACB_v1');
  else // If no matches are found
    print_and_exit('NOTFOUND');
  // ============== END XGD2 ==============
}
?>